scinumtools package
===================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   scinumtools.data
   scinumtools.math
   scinumtools.phys
   scinumtools.stats
   scinumtools.structs

Module contents
---------------

.. automodule:: scinumtools
   :members:
   :undoc-members:
   :show-inheritance:
